QueryResult class

Represents the result of a SQL query

Constructors

QueryResult({required List<Map<String, dynamic>> rows, required int rowCount, required List<String> columnNames})
QueryResult.fromJson(Map json)
Create QueryResult from JSON
factory

Properties

columnNames List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Check if result is empty
no setter
isNotEmpty bool
Check if result has data
no setter
rowCount int
final
rows List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited